@@ -1,51 +1,36 @@
-#' 1pl LSIRM model fixing gamma to 1 with normal likelihood
+#' 1PL LSIRM fixing gamma to 1 with normal likelihood
 #'
-#' @description \link{lsirm1pl_normal_fixed_gamma} is used to fit 1pl LSIRM model for continuous variable with gamma fixed to 1.
+#' @description \link{lsirm1pl_normal_fixed_gamma} is used to fit 1PL LSIRM for continuous variable with gamma fixed to 1.
 #' \link{lsirm1pl_normal_fixed_gamma} factorizes continuous item response matrix into column-wise item effect, row-wise respondent effect and further embeds interaction effect in a latent space, while ignoring the missing element under the assumption of missing at random. The resulting latent space provides an interaction map that represents interactions between respondents and items.
 #'
-#' @param data Matrix; continuous item response matrix to be analyzed. Each row is assumed to be respondent and its column values are assumed to be response to the corresponding item.
-#' @param ndim Numeric; dimension of latent space. default value is 2.
-#' @param niter Numeric; number of iterations to run MCMC sampling. default value is 15000.
-#' @param nburn Numeric; number of initial, pre-thinning, MCMC iterations to discard. default value is 2500.
-#' @param nthin Numeric;number of thinning, MCMC iterations to discard. default value is 5.
-#' @param nprint Numeric; MCMC samples is displayed during execution of MCMC chain for each \code{nprint}. default value is 500.
-#' @param jump_beta Numeric; jumping rule of the proposal density for beta. default value is 0.4.
-#' @param jump_theta Numeric; jumping rule of the proposal density for theta. default value is 1.0.
-#' @param jump_z Numeric; jumping rule of the proposal density for z. default value is 0.5.
-#' @param jump_w Numeric; jumping rule of the proposal density for w. default value is 0.5.
-#' @param pr_mean_beta Numeric; mean of normal prior for beta. default value is 0.
-#' @param pr_sd_beta Numeric; standard deviation of normal prior for beta. default value is 1.0.
-#' @param pr_mean_theta Numeric; mean of normal prior for theta. default value is 0.
-#' @param pr_a_theta Numeric; shape parameter of inverse gamma prior for variance of theta. default value is 0.001.
-#' @param pr_b_theta Numeric; scale parameter of inverse gamma prior for variance of theta. default value is 0.001.
-#' @param pr_a_eps Numeric; shape parameter of inverse gamma prior for variance of data likelihood. default value is 0.001.
-#' @param pr_b_eps Numeric; scale parameter of inverse gamma prior for variance of data likelihood default value is 0.001.
-#' @param verbose Logical; If TRUE, MCMC samples are printed for each \code{nprint}. default value is FALSE
-#' 
+#' @inheritParams lsirm1pl
+#' @param pr_a_eps Numeric; the shape parameter of inverse gamma prior for variance of data likelihood. Default is 0.001.
+#' @param pr_b_eps Numeric; the scale parameter of inverse gamma prior for variance of data likelihood Default is 0.001.
+#' @param verbose Logical; If TRUE, MCMC samples are printed for each \code{nprint}. default value is FALSE.
+#'
 #' @return \code{lsirm1pl_normal_fixed_gamma} returns an object of  list containing the following components:
-#'  \item{data}{data frame or matrix containing the variables in the model.}
-#'  \item{bic}{Numeric value with the corresponding BIC.}
-#'  \item{mcmc_inf}{number of mcmc iteration, burn-in periods, and thinning intervals.}
-#'  \item{map_inf}{value of log maximum a posterior and iteration number which have log maximum a posterior.}
-#'  \item{beta_estimate}{posterior estimation of beta.}
-#'  \item{theta_estimate}{posterior estimation of theta.}
-#'  \item{sigma_theta_estimate}{posterior estimation of standard deviation of theta.}
-#'  \item{sigma_estimate}{posterior estimation of standard deviation.}
-#'  \item{z_estimate}{posterior estimation of z.}
-#'  \item{w_estimate}{posterior estimation of w.}
-#'  \item{beta}{posterior samples of beta.}
-#'  \item{theta}{posterior samples of theta.}
-#'  \item{theta_sd}{posterior samples of standard deviation of theta.}
-#'  \item{sigma}{posterior samples of standard deviation.}
-#'  \item{z}{posterior samples of z. The output is 3-dimensional matrix with last axis represent the dimension of latent space.}
-#'  \item{w}{posterior samples of w. The output is 3-dimensional matrix with last axis represent the dimension of latent space.}
-#'  \item{accept_beta}{accept ratio of beta.}
-#'  \item{accept_theta}{accept ratio of theta.}
-#'  \item{accept_w}{accept ratio of w.}
-#'  \item{accept_z}{accept ratio of z.}
+#'  \item{data}{A data frame or matrix containing the variables used in the model.}
+#' \item{bic}{A numeric value representing the Bayesian Information Criterion (BIC).}
+#' \item{mcmc_inf}{Details about the number of MCMC iterations, burn-in periods, and thinning intervals.}
+#' \item{map_inf}{The log maximum a posteriori (MAP) value and the iteration number at which this MAP value occurs.}
+#' \item{beta_estimate}{Posterior estimates of the beta parameter.}
+#' \item{theta_estimate}{Posterior estimates of the theta parameter.}
+#' \item{sigma_theta_estimate}{Posterior estimates of the standard deviation of theta.}
+#' \item{z_estimate}{Posterior estimates of the z parameter.}
+#' \item{w_estimate}{Posterior estimates of the w parameter.}
+#' \item{beta}{Posterior samples of the beta parameter.}
+#' \item{theta}{Posterior samples of the theta parameter.}
+#' \item{theta_sd}{Posterior samples of the standard deviation of theta.}
+#' \item{z}{Posterior samples of the z parameter, represented as a 3-dimensional matrix where the last axis denotes the dimension of the latent space.}
+#' \item{w}{Posterior samples of the w parameter, represented as a 3-dimensional matrix where the last axis denotes the dimension of the latent space.}
+#' \item{accept_beta}{Acceptance ratio for the beta parameter.}
+#' \item{accept_theta}{Acceptance ratio for the theta parameter.}
+#' \item{accept_z}{Acceptance ratio for the z parameter.}
+#' \item{accept_w}{Acceptance ratio for the w parameter.}
+#'  \item{sigma_estimate}{Posterior estimates of the standard deviation.}
+#'  \item{sigma}{Posterior samples of the standard deviation.}
 #'
 #' @details \code{lsirm1pl_normal_fixed_gamma} models the continuous value of response by respondent \eqn{j} to item \eqn{i} with item effect \eqn{\beta_i}, respondent effect \eqn{\theta_j} and the distance between latent position \eqn{w_i} of item \eqn{i} and latent position \eqn{z_j} of respondent \eqn{j} in the shared metric space: \deqn{Y_{j,i} = \theta_j+\beta_i-||z_j-w_i|| + e_{j,i}} where the error \eqn{e_{j,i} \sim N(0,\sigma^2)}.
-#'
 #' @examples
 #' # generate example (continuous) item response matrix
 #' data     <- matrix(rnorm(500, mean = 0, sd = 1),ncol=10,nrow=50)
@@ -67,13 +52,16 @@ lsirm1pl_normal_fixed_gamma = function(data, ndim = 2, niter = 15000, nburn = 25
                                        pr_mean_beta = 0, pr_sd_beta = 1.0, pr_mean_theta = 0,
                                        pr_a_theta = 0.001, pr_b_theta = 0.001,
                                        pr_a_eps = 0.001, pr_b_eps = 0.001, verbose=FALSE){
-
+  if(niter < nburn){
+    stop("niter must be greater than burn-in process.")
+  }
   if(is.data.frame(data)){
     cname = colnames(data)
   }else{
     cname = paste("item", 1:ncol(data), sep=" ")
   }
-  cat("\n\nFitting with MCMC algorithm\n")
+  # cat("\n\nFitting with MCMC algorithm\n")
+
   output <- lsirm1pl_normal_fixed_gamma_cpp(as.matrix(data),  ndim,  niter,  nburn,  nthin,  nprint,
                                             jump_beta, jump_theta, jump_z, jump_w,
                                             pr_mean_beta, pr_sd_beta, pr_mean_theta,
@@ -90,13 +78,22 @@ lsirm1pl_normal_fixed_gamma = function(data, ndim = 2, niter = 15000, nburn = 25
   z.star = output$z[max.address,,]
   w.proc = array(0,dim=c(nmcmc,nitem,ndim))
   z.proc = array(0,dim=c(nmcmc,nsample,ndim))
-  cat("\n\nProcrustes Matching Analysis\n")
+  # cat("\n\nProcrustes Matching Analysis\n")
+cat("\n")
   for(iter in 1:nmcmc){
     z.iter = output$z[iter,,]
+    w.iter = output$w[iter,,]
+
+    if(ndim == 1){
+      z.iter = as.matrix(z.iter)
+      w.iter = as.matrix(w.iter)
+      z.star = as.matrix(z.star)
+      w.star = as.matrix(w.star)
+    }
+
     if(iter != max.address) z.proc[iter,,] = procrustes(z.iter,z.star)$X.new
     else z.proc[iter,,] = z.iter
 
-    w.iter = output$w[iter,,]
     if(iter != max.address) w.proc[iter,,] = procrustes(w.iter,w.star)$X.new
     else w.proc[iter,,] = w.iter
   }
@@ -114,7 +111,7 @@ lsirm1pl_normal_fixed_gamma = function(data, ndim = 2, niter = 15000, nburn = 25
   rownames(beta.summary) <- cname
 
   # Calculate BIC
-  cat("\n\nCalculate BIC\n")
+  # cat("\n\nCalculate BIC\n")
   log_like = log_likelihood_normal_cpp(as.matrix(data), ndim, as.matrix(beta.estimate), as.matrix(theta.estimate), 1, z.est, w.est, sigma.estimate, 99)
   p = nitem + nsample + 1 + ndim * nitem + ndim * nsample + 1
   bic = -2 * log_like[[1]] + p * log(nsample * nsample)
